@@ -1,3 +1,16 @@
+
+
+"""
+    Title: init.py
+    Author: Akash Dwivedi
+    Language: Python
+    Date Created: 26-07-2021
+    Date Modified: 14-08-2021
+    Description:
+        ###############################################################
+        ## Create a webhook on a specific repository   ## 
+         ###############################################################
+ """
 import requests
 import json
 import os 
@@ -49,11 +62,32 @@ class PayloadView():
         print("pull request = ", self.payload['action'])
         print("commits in pull: ", self.payload['pull_request'])
         return Response("success")
+
+
+# create webhook on a particular repo
+# '''create webhook on a particular repo '''
+         
+            # param : 
+            # token is the argument which is a aceess token for getting access to the
+            # github repository.
+            # username is github account name
+            # hostname is the server ip/address
+            # reponame is the repositery name
+            
+            # Variables Used:
+            # access_token : Stores the github access token 
+            # REPO_NAME : stores the reposirory 
+            # OWNER : stores the account name
+            # EVENTS : Events trigered
+            # HOST : server ip to run server
+
+            
 @click.command()
 def init():
     '''
     For initiating the webhook operation 
     '''
+    
     path=pathlib.Path().resolve()
     print("Your current directory  is : ", path)
     os.chdir(path)
